Mesh

Struct Mesh 

pub struct Mesh {
    pub nodes: Vec<[f64; 3]>,
    pub cells: Vec<[usize; 3]>,
}
Represents a standard 3D mesh. A Mesh consists of nodes representing points in 3D space, and cells which are triangles connecting these points.

Example

let nodes = vec![[0.0, 0.0, 0.0], [1.0, 0.0, 0.0], [0.0, 1.0, 0.0]];
let cells = vec![[0, 1, 2]];
let mesh = Mesh::new(nodes, cells);

Fields

nodes: Vec<[f64; 3]>cells: Vec<[usize; 3]>

Implementations

Source

impl Mesh

pub fn new(nodes: Vec<[f64; 3]>, cells: Vec<[usize; 3]>) -> Self

Constructs a new Mesh.

Arguments
  • nodes: Nodes of the mesh.
  • cells: Faces of the mesh.
pub fn from_stl(filename: &str) -> Result<Self>

Reads a mesh from an ASCII STL file using read_stl. See read_stl

pub fn from_obj(filename: &str) -> Result<Self>

Reads a mesh from an OBJ file using read_obj. See read_obj

pub fn write_stl( &self, filename: Option<&str>, format: Option<StlFormat>, ) -> Result<()>

Writes the mesh to an STL file. See write_stl

pub fn write_obj(&self, filename: Option<&str>) -> Result<()>

Writes the mesh to an OBJ file. See write_obj

pub fn triangles(&self) -> Vec<[[f64; 3]; 3]>

Get nodes that make up cell triangles. See get_mesh_triangles

pub fn cell_normals(&self) -> Vec<[f64; 3]>

Get cell normals. See get_mesh_cell_normals

pub fn slice(&self, origin: [f64; 3], normal: [f64; 3]) -> Option<Vec<[f64; 3]>>

Get nodes that are interpolated onto a slicing plane. See find_node_intersections_with_plane

pub fn clip(&self, origin: [f64; 3], normal: [f64; 3]) -> Mesh

Get mesh in direction of plane. See clip_mesh_from_plane