scale_node

Function scale_node 

pub fn scale_node(node: &mut [f64; 3], scaling: &[f64; 3], origin: &[f64; 3])
Scales a node by the given scaling factor, relative to a given origin.

Arguments

  • node: A mutable 3D node.
  • scaling: An array of f64 that represents the scaling factors for each dimension.
  • origin: The point relative to which the scaling should be performed.