FreeFormDeformer

Struct FreeFormDeformer 

pub struct FreeFormDeformer {
    pub original_design_block: DesignBlock,
    pub affine_weights_pre: [[f64; 4]; 4],
    pub affine_weights_post: [[f64; 4]; 4],
}
Free-form deformer

Fields

original_design_block: DesignBlock

Input control node block.

affine_weights_pre: [[f64; 4]; 4]

Affine weights pre transformation

affine_weights_post: [[f64; 4]; 4]

Affine weights post transformation

Implementations

Source

impl FreeFormDeformer

pub fn new(original_design_block: DesignBlock) -> Result<Self>

Instantiates a new FreeFormDeformer instance.

Arguments
  • original_design_block: A DesignBlock containing the original node positions.
Returns

A new FreeFormDeformer instance or an error string if creation fails.

pub fn deform( &self, points: &[[f64; 3]], deformed_design_nodes: &[[f64; 3]], ) -> Result<Vec<[f64; 3]>>

Deform points based on deltas of the control points.

Arguments
  • points: New input mesh nodes to predict the deformed positions for.
  • deformed_design_nodes: New nodal positions of design box.
Returns

New points or an error string if deformation fails.