Module transforms

Module transforms 

Functions

apply_affine_transform
Apply an affine transformation to a set of 3D points.
apply_bernstein_transform
Apply a Bernstein transform to a set of 3D points.